from setuptools import setup

setup(
    name='banking_system',
    version='1.0.4',
    author='Kunal Kumar',
    description='A simple banking management system package',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    packages=['banking_system'],
    install_requires=[],  # Add dependencies if any
)
